pub unsafe extern "C" fn GPIO_get_inputs(
this_gpio: *mut gpio_instance_t,
) -> u32Expand description
The GPIO_get_inputs() function is used to read the state of all GPIOs configured as inputs.
@param this_gpio The this_gpio parameter is a pointer to the gpio_instance_t structure holding all the data regarding the CoreGPIO instance controlled through this function call.
@return This function returns a 32-bit unsigned integer, where each bit represents the state of an input. The least significant bit represents the state of GPIO 0, and the most significant bit represents the state of GPIO 31.