MSS_CFM_runtime_register

Function MSS_CFM_runtime_register 

pub unsafe extern "C" fn MSS_CFM_runtime_register(referenceCount: u32)
The MSS_CFM_runtime_register() function is used to set how many reference clock cycles the frequency and time measurement should be made. The register does NOT change during oepration

@param refcount The reference count value.