MSS_MAC_set_tx_callback

Function MSS_MAC_set_tx_callback 

pub unsafe extern "C" fn MSS_MAC_set_tx_callback(
    this_mac: *mut mss_mac_instance_t,
    queue_no: u32,
    tx_complete_handler: mss_mac_transmit_callback_t,
)
//** The MSS_MAC_set_tx_callback() function registers the function that will be called by the Ethernet MAC driver when a packet has been sent on the specified queue.

@param this_mac This parameter is a pointer to one of the global mss_mac_instance_t structures which identifies the MAC that the function is to operate on. There are between 1 and 4 such structures identifying pMAC0, eMAC0, pMAC1 and eMAC1.

@param queue_no This parameter identifies the queue which this callback function will service. For single queue devices, this should be set to 0 for compatibility purposes.

@param tx_complete_handler This parameter is a pointer to the function that will be called when a packet is sent by the Ethernet MAC on the selected queue.

@return This function does not return a value.