MSS_SYS_debug_write_mem

Function MSS_SYS_debug_write_mem 

pub unsafe extern "C" fn MSS_SYS_debug_write_mem(
    mem_addr: u16,
    n_words: u16,
    mss_addr: u64,
    mb_offset: u16,
) -> u16
The MSS_SYS_debug_write_mem() function issues the MEM Write Debug Service to the system controller. This service provides an interface to write data from the memory peripheral that is specified.

Please refer to theory of operation -> reference documents section for more information about the service.

@param mem_addr The mem_addr parameter sets the target address within the currently selected memory peripheral for subsequent mem write & mem read instructions. @param n_words The n_words parameter value depends on memtype. The maximum limit is the size of memory. @param mss_addr The mss_addr parameter specifies the MSS RAM area where to copy the MEM Read data to. Note that all accesses will be done with MSS User privileges. @param mb_offset The mb_offset parameter specifies the offset from the start of mailbox where the data related to this service is available. All accesses to the mailbox are of word length (4 bytes). A value 10 (decimal) of this parameter would mean that the data access area for this service, in the mailbox starts from 11th word (offset 10). @return This function returns a value to indicate whether the service was executed successfully or not. A zero value indicates that the service was executed successfully.