pub unsafe extern "C" fn MSS_SYS_debug_write_probe(
prb_addr: u8,
ipseg_addr: u8,
iprow_addr: u8,
pwmask: u32,
pwdata: u32,
mb_offset: u16,
) -> u16Expand description
The MSS_SYS_debug_write_probe() function will issue the probe write debug service to the system controller. It service will writes up to 18 bits of data to selected probe address.
Please refer to theory of operation -> reference documents section for more information about the service.
@param prb_addr The prb_addr parameter specifies the probe address. @param ipseg_addr The ipseg_addr parameter specifies the probe segment address. @param iprow_addr The iprow_addr parameter specifies the probe row address. prb_addr, ipseg_addr and iprow_addr parameters specifies the target address of one of the 59 words within a probe module. @param pwmask The pwmask parameter specifies the which of the 18 bits of pwdata shall be written to selected probe module. @param pwdata The pwdata parameter specifies the value to be written on selected probe registers. Example: If PWMASK[i] is ‘1’ then probe register i will be written to the value specified by PWDATA[i]. @param mb_offset The mb_offset parameter specifies the offset from the start of mailbox where the data related to this service is available. All accesses to the mailbox are of word length (4 bytes). A value 10 (decimal) of this parameter would mean that the data access area for this service, in the mailbox starts from 11th word (offset 10). @return This function returns a value to indicate whether the service was executed successfully or not. A zero value indicates that the service was executed successfully.