pub unsafe extern "C" fn PLIC_GetPriority(IRQn: PLIC_IRQn_Type) -> u32Expand description
/ /** The function PLIC_GetPriority() returns the priority for the external interrupt for the interrupt number indicated by the parameter IRQn.
pub unsafe extern "C" fn PLIC_GetPriority(IRQn: PLIC_IRQn_Type) -> u32/ /** The function PLIC_GetPriority() returns the priority for the external interrupt for the interrupt number indicated by the parameter IRQn.