PLIC_SetPriority_Threshold

Function PLIC_SetPriority_Threshold 

pub unsafe extern "C" fn PLIC_SetPriority_Threshold(threshold: u32)
/ /**

The function PLIC_SetPriority_Threshold() sets the threshold for a particular hart. The default threshold on reset is 0. The PFSoC Core Complex supports setting of an interrupt priority threshold via the threshold register. The threshold is a WARL field, where the PFSoC Core Complex supports a maximum threshold of 7. The PFSoC Core Complex will mask all PLIC interrupts of a priority less than or equal to threshold. For example, a threshold value of zero permits all interrupts with non-zero priority, whereas a value of 7 masks all interrupts.