pub unsafe extern "C" fn PLIC_init()Expand description
The function PLIC_init() initializes the PLIC controller and enables the global external interrupt bit.
pub unsafe extern "C" fn PLIC_init()The function PLIC_init() initializes the PLIC controller and enables the global external interrupt bit.