pub unsafe extern "C" fn config_l2_cache()Expand description
//** The config_l2_cache() function is used to setup scratchpad. It will be used by bootloader. e.g. Hart Software Services (HSS) This code should only be executed from E51 to be functional. Configure the L2 cache memory:
- Set the number of cache ways used as cache based on the MSS Configurator settings.
- Configure some of the enabled ways as scratchpad based on space allocated by the MSS configurator.
Example: @code // When called from assembly call config_l2_cache call end_l2_scratchpad_address # end address returned in a0 call .clear_scratchpad @endcode