pub unsafe extern "C" fn init_bus_error_unit() -> u8Expand description
//** The init_bus_error_unit() function is used to setup the Bus Error Unit (BEU) for all the harts used in the system. Define the defines (LIBERO_SETTING_BEU_ENABLE_HART0 etc) in mss_sw_config.h if you want to use non default values. Example: @code when all mem init, call the setup function init_bus_error_unit(); @endcode