__mss_spi_instance_t

Struct __mss_spi_instance_t 

#[repr(C)]
pub struct __mss_spi_instance_t {
Show 19 fields pub hw_reg: *mut SPI_TypeDef, pub irqn: u8, pub slave_tx_buffer: *const u8, pub slave_tx_size: u32, pub slave_tx_idx: u32, pub resp_tx_buffer: *const u8, pub resp_buff_size: u32, pub resp_buff_tx_idx: u32, pub cmd_handler: mss_spi_block_rx_handler_t, pub cmd_done: u32, pub slave_rx_buffer: *mut u8, pub slave_rx_size: u32, pub slave_rx_idx: u32, pub slaves_cfg: [mss_spi_slave_cfg_t; 2], pub frame_rx_handler: mss_spi_frame_rx_handler_t, pub slave_tx_frame: u32, pub block_rx_handler: mss_spi_block_rx_handler_t, pub slave_xfer_mode: mss_spi_sxfer_mode_t, pub buffer_overflow_handler: mss_spi_oveflow_handler_t,
}
There is one instance of this structure for each of the Microprocessor Subsystem’s SPIs. Instances of this structure are used to identify a specific SPI. A pointer to an instance of the mss_spi_instance_t structure is passed as the first parameter to MSS SPI driver functions to identify which SPI should perform the requested operation.

Fields

hw_reg: *mut SPI_TypeDefirqn: u8slave_tx_buffer: *const u8slave_tx_size: u32slave_tx_idx: u32resp_tx_buffer: *const u8resp_buff_size: u32resp_buff_tx_idx: u32cmd_handler: mss_spi_block_rx_handler_tcmd_done: u32slave_rx_buffer: *mut u8slave_rx_size: u32slave_rx_idx: u32slaves_cfg: [mss_spi_slave_cfg_t; 2]frame_rx_handler: mss_spi_frame_rx_handler_tslave_tx_frame: u32block_rx_handler: mss_spi_block_rx_handler_tslave_xfer_mode: mss_spi_sxfer_mode_tbuffer_overflow_handler: mss_spi_oveflow_handler_t