mss_can_instance_t

Type Alias mss_can_instance_t 

pub type mss_can_instance_t = can_instance;
The structure mss_can_instance_t is used by the driver to manage the configuration and operation of each MSS CAN peripheral. The instance content should only be accessed by using the respective API functions.

Each API function has a pointer to this instance as first argument.

Aliased Type

#[repr(C)]
pub struct mss_can_instance_t { pub hw_reg: *mut CAN_device, pub irqn: u8, pub int_type: u8, pub basic_can_rx_mb: u8, pub basic_can_tx_mb: u8, }

Fields

hw_reg: *mut CAN_deviceirqn: u8int_type: u8

< 0 => local, 1 => PLIC

basic_can_rx_mb: u8basic_can_tx_mb: u8