pub type mss_spi_instance_t = __mss_spi_instance_t;Expand description
There is one instance of this structure for each of the Microprocessor Subsystem’s SPIs. Instances of this structure are used to identify a specific SPI. A pointer to an instance of the mss_spi_instance_t structure is passed as the first parameter to MSS SPI driver functions to identify which SPI should perform the requested operation.
Aliased Type
#[repr(C)]pub struct mss_spi_instance_t {Show 19 fields
pub hw_reg: *mut SPI_TypeDef,
pub irqn: u8,
pub slave_tx_buffer: *const u8,
pub slave_tx_size: u32,
pub slave_tx_idx: u32,
pub resp_tx_buffer: *const u8,
pub resp_buff_size: u32,
pub resp_buff_tx_idx: u32,
pub cmd_handler: Option<unsafe extern "C" fn(*mut u8, u32)>,
pub cmd_done: u32,
pub slave_rx_buffer: *mut u8,
pub slave_rx_size: u32,
pub slave_rx_idx: u32,
pub slaves_cfg: [__mss_spi_slave_cfg_t; 2],
pub frame_rx_handler: Option<unsafe extern "C" fn(u32)>,
pub slave_tx_frame: u32,
pub block_rx_handler: Option<unsafe extern "C" fn(*mut u8, u32)>,
pub slave_xfer_mode: u32,
pub buffer_overflow_handler: Option<unsafe extern "C" fn(u8)>,
}Fields
hw_reg: *mut SPI_TypeDefirqn: u8slave_tx_buffer: *const u8slave_tx_size: u32slave_tx_idx: u32resp_tx_buffer: *const u8resp_buff_size: u32resp_buff_tx_idx: u32cmd_handler: Option<unsafe extern "C" fn(*mut u8, u32)>cmd_done: u32slave_rx_buffer: *mut u8slave_rx_size: u32slave_rx_idx: u32slaves_cfg: [__mss_spi_slave_cfg_t; 2]frame_rx_handler: Option<unsafe extern "C" fn(u32)>slave_tx_frame: u32block_rx_handler: Option<unsafe extern "C" fn(*mut u8, u32)>slave_xfer_mode: u32buffer_overflow_handler: Option<unsafe extern "C" fn(u8)>